@@ -4,10 +4,10 @@ use crate::staking_types::{Validator, ValidatorDelegation, ValidatorUnbondingDel
 use crate::{LCDResult, LCDResultVec, LCDTypeValue, Terra};
 
 pub struct Auth<'a> {
-    terra: &'a Terra<'a>,
+    terra: &'a Terra,
 }
 impl Auth<'_> {
-    pub fn create<'a>(terra: &'a Terra) -> Auth<'a> {
+    pub fn create(terra: &'_ Terra) -> Auth<'_> {
         Auth { terra }
     }
     pub async fn account(
